@@ -27,10 +27,10 @@
 namespace Gnome
 {
 
-typedef SigC::Slot0<void>        Callback;
-typedef SigC::Slot0<gdouble>     ProgressCallback;
-typedef SigC::Slot1<void, gint>   ReplyCallback;
-typedef SigC::Slot1<void, Glib::ustring> StringCallback;
+typedef sigc::slot<void>        Callback;
+typedef sigc::slot<gdouble>     ProgressCallback;
+typedef sigc::slot<void, gint>   ReplyCallback;
+typedef sigc::slot<void, Glib::ustring> StringCallback;
 
 } /* namespace Gnome */
 
